@@ -41,7 +41,9 @@ else:
 __all__ = (
     "AddAttributesActivityTypeDef",
     "BatchPutMessageErrorEntryTypeDef",
+    "BatchPutMessageRequestRequestTypeDef",
     "BatchPutMessageResponseTypeDef",
+    "CancelPipelineReprocessingRequestRequestTypeDef",
     "ChannelActivityTypeDef",
     "ChannelMessagesTypeDef",
     "ChannelStatisticsTypeDef",
@@ -51,10 +53,15 @@ __all__ = (
     "ChannelTypeDef",
     "ColumnTypeDef",
     "ContainerDatasetActionTypeDef",
+    "CreateChannelRequestRequestTypeDef",
     "CreateChannelResponseTypeDef",
+    "CreateDatasetContentRequestRequestTypeDef",
     "CreateDatasetContentResponseTypeDef",
+    "CreateDatasetRequestRequestTypeDef",
     "CreateDatasetResponseTypeDef",
+    "CreateDatastoreRequestRequestTypeDef",
     "CreateDatastoreResponseTypeDef",
+    "CreatePipelineRequestRequestTypeDef",
     "CreatePipelineResponseTypeDef",
     "CustomerManagedChannelS3StorageSummaryTypeDef",
     "CustomerManagedChannelS3StorageTypeDef",
@@ -79,29 +86,45 @@ __all__ = (
     "DatastoreStorageTypeDef",
     "DatastoreSummaryTypeDef",
     "DatastoreTypeDef",
+    "DeleteChannelRequestRequestTypeDef",
+    "DeleteDatasetContentRequestRequestTypeDef",
+    "DeleteDatasetRequestRequestTypeDef",
+    "DeleteDatastoreRequestRequestTypeDef",
+    "DeletePipelineRequestRequestTypeDef",
     "DeltaTimeSessionWindowConfigurationTypeDef",
     "DeltaTimeTypeDef",
+    "DescribeChannelRequestRequestTypeDef",
     "DescribeChannelResponseTypeDef",
+    "DescribeDatasetRequestRequestTypeDef",
     "DescribeDatasetResponseTypeDef",
+    "DescribeDatastoreRequestRequestTypeDef",
     "DescribeDatastoreResponseTypeDef",
     "DescribeLoggingOptionsResponseTypeDef",
+    "DescribePipelineRequestRequestTypeDef",
     "DescribePipelineResponseTypeDef",
     "DeviceRegistryEnrichActivityTypeDef",
     "DeviceShadowEnrichActivityTypeDef",
     "EstimatedResourceSizeTypeDef",
     "FileFormatConfigurationTypeDef",
     "FilterActivityTypeDef",
+    "GetDatasetContentRequestRequestTypeDef",
     "GetDatasetContentResponseTypeDef",
     "GlueConfigurationTypeDef",
     "IotEventsDestinationConfigurationTypeDef",
     "LambdaActivityTypeDef",
     "LateDataRuleConfigurationTypeDef",
     "LateDataRuleTypeDef",
+    "ListChannelsRequestRequestTypeDef",
     "ListChannelsResponseTypeDef",
+    "ListDatasetContentsRequestRequestTypeDef",
     "ListDatasetContentsResponseTypeDef",
+    "ListDatasetsRequestRequestTypeDef",
     "ListDatasetsResponseTypeDef",
+    "ListDatastoresRequestRequestTypeDef",
     "ListDatastoresResponseTypeDef",
+    "ListPipelinesRequestRequestTypeDef",
     "ListPipelinesResponseTypeDef",
+    "ListTagsForResourceRequestRequestTypeDef",
     "ListTagsForResourceResponseTypeDef",
     "LoggingOptionsTypeDef",
     "MathActivityTypeDef",
@@ -113,22 +136,33 @@ __all__ = (
     "PipelineActivityTypeDef",
     "PipelineSummaryTypeDef",
     "PipelineTypeDef",
+    "PutLoggingOptionsRequestRequestTypeDef",
     "QueryFilterTypeDef",
     "RemoveAttributesActivityTypeDef",
     "ReprocessingSummaryTypeDef",
     "ResourceConfigurationTypeDef",
+    "ResponseMetadataTypeDef",
     "RetentionPeriodTypeDef",
+    "RunPipelineActivityRequestRequestTypeDef",
     "RunPipelineActivityResponseTypeDef",
     "S3DestinationConfigurationTypeDef",
+    "SampleChannelDataRequestRequestTypeDef",
     "SampleChannelDataResponseTypeDef",
     "ScheduleTypeDef",
     "SchemaDefinitionTypeDef",
     "SelectAttributesActivityTypeDef",
     "SqlQueryDatasetActionTypeDef",
+    "StartPipelineReprocessingRequestRequestTypeDef",
     "StartPipelineReprocessingResponseTypeDef",
+    "TagResourceRequestRequestTypeDef",
     "TagTypeDef",
     "TimestampPartitionTypeDef",
     "TriggeringDatasetTypeDef",
+    "UntagResourceRequestRequestTypeDef",
+    "UpdateChannelRequestRequestTypeDef",
+    "UpdateDatasetRequestRequestTypeDef",
+    "UpdateDatastoreRequestRequestTypeDef",
+    "UpdatePipelineRequestRequestTypeDef",
     "VariableTypeDef",
     "VersioningConfigurationTypeDef",
 )
@@ -165,12 +199,28 @@ BatchPutMessageErrorEntryTypeDef = TypedDict(
     total=False,
 )
 
+BatchPutMessageRequestRequestTypeDef = TypedDict(
+    "BatchPutMessageRequestRequestTypeDef",
+    {
+        "channelName": str,
+        "messages": List["MessageTypeDef"],
+    },
+)
+
 BatchPutMessageResponseTypeDef = TypedDict(
     "BatchPutMessageResponseTypeDef",
     {
         "batchPutMessageErrorEntries": List["BatchPutMessageErrorEntryTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+CancelPipelineReprocessingRequestRequestTypeDef = TypedDict(
+    "CancelPipelineReprocessingRequestRequestTypeDef",
+    {
+        "pipelineName": str,
+        "reprocessingId": str,
     },
-    total=False,
 )
 
 _RequiredChannelActivityTypeDef = TypedDict(
@@ -286,51 +336,170 @@ class ContainerDatasetActionTypeDef(
     pass
 
 
+_RequiredCreateChannelRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateChannelRequestRequestTypeDef",
+    {
+        "channelName": str,
+    },
+)
+_OptionalCreateChannelRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateChannelRequestRequestTypeDef",
+    {
+        "channelStorage": "ChannelStorageTypeDef",
+        "retentionPeriod": "RetentionPeriodTypeDef",
+        "tags": List["TagTypeDef"],
+    },
+    total=False,
+)
+
+
+class CreateChannelRequestRequestTypeDef(
+    _RequiredCreateChannelRequestRequestTypeDef, _OptionalCreateChannelRequestRequestTypeDef
+):
+    pass
+
+
 CreateChannelResponseTypeDef = TypedDict(
     "CreateChannelResponseTypeDef",
     {
         "channelName": str,
         "channelArn": str,
         "retentionPeriod": "RetentionPeriodTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
-CreateDatasetContentResponseTypeDef = TypedDict(
-    "CreateDatasetContentResponseTypeDef",
+_RequiredCreateDatasetContentRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateDatasetContentRequestRequestTypeDef",
+    {
+        "datasetName": str,
+    },
+)
+_OptionalCreateDatasetContentRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateDatasetContentRequestRequestTypeDef",
     {
         "versionId": str,
     },
     total=False,
 )
 
+
+class CreateDatasetContentRequestRequestTypeDef(
+    _RequiredCreateDatasetContentRequestRequestTypeDef,
+    _OptionalCreateDatasetContentRequestRequestTypeDef,
+):
+    pass
+
+
+CreateDatasetContentResponseTypeDef = TypedDict(
+    "CreateDatasetContentResponseTypeDef",
+    {
+        "versionId": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredCreateDatasetRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateDatasetRequestRequestTypeDef",
+    {
+        "datasetName": str,
+        "actions": List["DatasetActionTypeDef"],
+    },
+)
+_OptionalCreateDatasetRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateDatasetRequestRequestTypeDef",
+    {
+        "triggers": List["DatasetTriggerTypeDef"],
+        "contentDeliveryRules": List["DatasetContentDeliveryRuleTypeDef"],
+        "retentionPeriod": "RetentionPeriodTypeDef",
+        "versioningConfiguration": "VersioningConfigurationTypeDef",
+        "tags": List["TagTypeDef"],
+        "lateDataRules": List["LateDataRuleTypeDef"],
+    },
+    total=False,
+)
+
+
+class CreateDatasetRequestRequestTypeDef(
+    _RequiredCreateDatasetRequestRequestTypeDef, _OptionalCreateDatasetRequestRequestTypeDef
+):
+    pass
+
+
 CreateDatasetResponseTypeDef = TypedDict(
     "CreateDatasetResponseTypeDef",
     {
         "datasetName": str,
         "datasetArn": str,
         "retentionPeriod": "RetentionPeriodTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredCreateDatastoreRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateDatastoreRequestRequestTypeDef",
+    {
+        "datastoreName": str,
+    },
+)
+_OptionalCreateDatastoreRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateDatastoreRequestRequestTypeDef",
+    {
+        "datastoreStorage": "DatastoreStorageTypeDef",
+        "retentionPeriod": "RetentionPeriodTypeDef",
+        "tags": List["TagTypeDef"],
+        "fileFormatConfiguration": "FileFormatConfigurationTypeDef",
+        "datastorePartitions": "DatastorePartitionsTypeDef",
     },
     total=False,
 )
 
+
+class CreateDatastoreRequestRequestTypeDef(
+    _RequiredCreateDatastoreRequestRequestTypeDef, _OptionalCreateDatastoreRequestRequestTypeDef
+):
+    pass
+
+
 CreateDatastoreResponseTypeDef = TypedDict(
     "CreateDatastoreResponseTypeDef",
     {
         "datastoreName": str,
         "datastoreArn": str,
         "retentionPeriod": "RetentionPeriodTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredCreatePipelineRequestRequestTypeDef = TypedDict(
+    "_RequiredCreatePipelineRequestRequestTypeDef",
+    {
+        "pipelineName": str,
+        "pipelineActivities": List["PipelineActivityTypeDef"],
+    },
+)
+_OptionalCreatePipelineRequestRequestTypeDef = TypedDict(
+    "_OptionalCreatePipelineRequestRequestTypeDef",
+    {
+        "tags": List["TagTypeDef"],
     },
     total=False,
 )
 
+
+class CreatePipelineRequestRequestTypeDef(
+    _RequiredCreatePipelineRequestRequestTypeDef, _OptionalCreatePipelineRequestRequestTypeDef
+):
+    pass
+
+
 CreatePipelineResponseTypeDef = TypedDict(
     "CreatePipelineResponseTypeDef",
     {
         "pipelineName": str,
         "pipelineArn": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 CustomerManagedChannelS3StorageSummaryTypeDef = TypedDict(
@@ -607,6 +776,56 @@ DatastoreTypeDef = TypedDict(
     total=False,
 )
 
+DeleteChannelRequestRequestTypeDef = TypedDict(
+    "DeleteChannelRequestRequestTypeDef",
+    {
+        "channelName": str,
+    },
+)
+
+_RequiredDeleteDatasetContentRequestRequestTypeDef = TypedDict(
+    "_RequiredDeleteDatasetContentRequestRequestTypeDef",
+    {
+        "datasetName": str,
+    },
+)
+_OptionalDeleteDatasetContentRequestRequestTypeDef = TypedDict(
+    "_OptionalDeleteDatasetContentRequestRequestTypeDef",
+    {
+        "versionId": str,
+    },
+    total=False,
+)
+
+
+class DeleteDatasetContentRequestRequestTypeDef(
+    _RequiredDeleteDatasetContentRequestRequestTypeDef,
+    _OptionalDeleteDatasetContentRequestRequestTypeDef,
+):
+    pass
+
+
+DeleteDatasetRequestRequestTypeDef = TypedDict(
+    "DeleteDatasetRequestRequestTypeDef",
+    {
+        "datasetName": str,
+    },
+)
+
+DeleteDatastoreRequestRequestTypeDef = TypedDict(
+    "DeleteDatastoreRequestRequestTypeDef",
+    {
+        "datastoreName": str,
+    },
+)
+
+DeletePipelineRequestRequestTypeDef = TypedDict(
+    "DeletePipelineRequestRequestTypeDef",
+    {
+        "pipelineName": str,
+    },
+)
+
 DeltaTimeSessionWindowConfigurationTypeDef = TypedDict(
     "DeltaTimeSessionWindowConfigurationTypeDef",
     {
@@ -622,46 +841,102 @@ DeltaTimeTypeDef = TypedDict(
     },
 )
 
+_RequiredDescribeChannelRequestRequestTypeDef = TypedDict(
+    "_RequiredDescribeChannelRequestRequestTypeDef",
+    {
+        "channelName": str,
+    },
+)
+_OptionalDescribeChannelRequestRequestTypeDef = TypedDict(
+    "_OptionalDescribeChannelRequestRequestTypeDef",
+    {
+        "includeStatistics": bool,
+    },
+    total=False,
+)
+
+
+class DescribeChannelRequestRequestTypeDef(
+    _RequiredDescribeChannelRequestRequestTypeDef, _OptionalDescribeChannelRequestRequestTypeDef
+):
+    pass
+
+
 DescribeChannelResponseTypeDef = TypedDict(
     "DescribeChannelResponseTypeDef",
     {
         "channel": "ChannelTypeDef",
         "statistics": "ChannelStatisticsTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+DescribeDatasetRequestRequestTypeDef = TypedDict(
+    "DescribeDatasetRequestRequestTypeDef",
+    {
+        "datasetName": str,
     },
-    total=False,
 )
 
 DescribeDatasetResponseTypeDef = TypedDict(
     "DescribeDatasetResponseTypeDef",
     {
         "dataset": "DatasetTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredDescribeDatastoreRequestRequestTypeDef = TypedDict(
+    "_RequiredDescribeDatastoreRequestRequestTypeDef",
+    {
+        "datastoreName": str,
+    },
+)
+_OptionalDescribeDatastoreRequestRequestTypeDef = TypedDict(
+    "_OptionalDescribeDatastoreRequestRequestTypeDef",
+    {
+        "includeStatistics": bool,
     },
     total=False,
 )
 
+
+class DescribeDatastoreRequestRequestTypeDef(
+    _RequiredDescribeDatastoreRequestRequestTypeDef, _OptionalDescribeDatastoreRequestRequestTypeDef
+):
+    pass
+
+
 DescribeDatastoreResponseTypeDef = TypedDict(
     "DescribeDatastoreResponseTypeDef",
     {
         "datastore": "DatastoreTypeDef",
         "statistics": "DatastoreStatisticsTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 DescribeLoggingOptionsResponseTypeDef = TypedDict(
     "DescribeLoggingOptionsResponseTypeDef",
     {
         "loggingOptions": "LoggingOptionsTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+DescribePipelineRequestRequestTypeDef = TypedDict(
+    "DescribePipelineRequestRequestTypeDef",
+    {
+        "pipelineName": str,
     },
-    total=False,
 )
 
 DescribePipelineResponseTypeDef = TypedDict(
     "DescribePipelineResponseTypeDef",
     {
         "pipeline": "PipelineTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 _RequiredDeviceRegistryEnrichActivityTypeDef = TypedDict(
@@ -750,14 +1025,35 @@ class FilterActivityTypeDef(_RequiredFilterActivityTypeDef, _OptionalFilterActiv
     pass
 
 
+_RequiredGetDatasetContentRequestRequestTypeDef = TypedDict(
+    "_RequiredGetDatasetContentRequestRequestTypeDef",
+    {
+        "datasetName": str,
+    },
+)
+_OptionalGetDatasetContentRequestRequestTypeDef = TypedDict(
+    "_OptionalGetDatasetContentRequestRequestTypeDef",
+    {
+        "versionId": str,
+    },
+    total=False,
+)
+
+
+class GetDatasetContentRequestRequestTypeDef(
+    _RequiredGetDatasetContentRequestRequestTypeDef, _OptionalGetDatasetContentRequestRequestTypeDef
+):
+    pass
+
+
 GetDatasetContentResponseTypeDef = TypedDict(
     "GetDatasetContentResponseTypeDef",
     {
         "entries": List["DatasetEntryTypeDef"],
         "timestamp": datetime,
         "status": "DatasetContentStatusTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 GlueConfigurationTypeDef = TypedDict(
@@ -824,20 +1120,63 @@ class LateDataRuleTypeDef(_RequiredLateDataRuleTypeDef, _OptionalLateDataRuleTyp
     pass
 
 
+ListChannelsRequestRequestTypeDef = TypedDict(
+    "ListChannelsRequestRequestTypeDef",
+    {
+        "nextToken": str,
+        "maxResults": int,
+    },
+    total=False,
+)
+
 ListChannelsResponseTypeDef = TypedDict(
     "ListChannelsResponseTypeDef",
     {
         "channelSummaries": List["ChannelSummaryTypeDef"],
         "nextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredListDatasetContentsRequestRequestTypeDef = TypedDict(
+    "_RequiredListDatasetContentsRequestRequestTypeDef",
+    {
+        "datasetName": str,
+    },
+)
+_OptionalListDatasetContentsRequestRequestTypeDef = TypedDict(
+    "_OptionalListDatasetContentsRequestRequestTypeDef",
+    {
+        "nextToken": str,
+        "maxResults": int,
+        "scheduledOnOrAfter": Union[datetime, str],
+        "scheduledBefore": Union[datetime, str],
     },
     total=False,
 )
 
+
+class ListDatasetContentsRequestRequestTypeDef(
+    _RequiredListDatasetContentsRequestRequestTypeDef,
+    _OptionalListDatasetContentsRequestRequestTypeDef,
+):
+    pass
+
+
 ListDatasetContentsResponseTypeDef = TypedDict(
     "ListDatasetContentsResponseTypeDef",
     {
         "datasetContentSummaries": List["DatasetContentSummaryTypeDef"],
         "nextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+ListDatasetsRequestRequestTypeDef = TypedDict(
+    "ListDatasetsRequestRequestTypeDef",
+    {
+        "nextToken": str,
+        "maxResults": int,
     },
     total=False,
 )
@@ -847,6 +1186,15 @@ ListDatasetsResponseTypeDef = TypedDict(
     {
         "datasetSummaries": List["DatasetSummaryTypeDef"],
         "nextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+ListDatastoresRequestRequestTypeDef = TypedDict(
+    "ListDatastoresRequestRequestTypeDef",
+    {
+        "nextToken": str,
+        "maxResults": int,
     },
     total=False,
 )
@@ -856,6 +1204,15 @@ ListDatastoresResponseTypeDef = TypedDict(
     {
         "datastoreSummaries": List["DatastoreSummaryTypeDef"],
         "nextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+ListPipelinesRequestRequestTypeDef = TypedDict(
+    "ListPipelinesRequestRequestTypeDef",
+    {
+        "nextToken": str,
+        "maxResults": int,
     },
     total=False,
 )
@@ -865,16 +1222,23 @@ ListPipelinesResponseTypeDef = TypedDict(
     {
         "pipelineSummaries": List["PipelineSummaryTypeDef"],
         "nextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+ListTagsForResourceRequestRequestTypeDef = TypedDict(
+    "ListTagsForResourceRequestRequestTypeDef",
+    {
+        "resourceArn": str,
     },
-    total=False,
 )
 
 ListTagsForResourceResponseTypeDef = TypedDict(
     "ListTagsForResourceResponseTypeDef",
     {
         "tags": List["TagTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 LoggingOptionsTypeDef = TypedDict(
@@ -988,6 +1352,13 @@ PipelineTypeDef = TypedDict(
     total=False,
 )
 
+PutLoggingOptionsRequestRequestTypeDef = TypedDict(
+    "PutLoggingOptionsRequestRequestTypeDef",
+    {
+        "loggingOptions": "LoggingOptionsTypeDef",
+    },
+)
+
 QueryFilterTypeDef = TypedDict(
     "QueryFilterTypeDef",
     {
@@ -1036,6 +1407,17 @@ ResourceConfigurationTypeDef = TypedDict(
     },
 )
 
+ResponseMetadataTypeDef = TypedDict(
+    "ResponseMetadataTypeDef",
+    {
+        "RequestId": str,
+        "HostId": str,
+        "HTTPStatusCode": int,
+        "HTTPHeaders": Dict[str, Any],
+        "RetryAttempts": int,
+    },
+)
+
 RetentionPeriodTypeDef = TypedDict(
     "RetentionPeriodTypeDef",
     {
@@ -1045,13 +1427,21 @@ RetentionPeriodTypeDef = TypedDict(
     total=False,
 )
 
+RunPipelineActivityRequestRequestTypeDef = TypedDict(
+    "RunPipelineActivityRequestRequestTypeDef",
+    {
+        "pipelineActivity": "PipelineActivityTypeDef",
+        "payloads": List[Union[bytes, IO[bytes], StreamingBody]],
+    },
+)
+
 RunPipelineActivityResponseTypeDef = TypedDict(
     "RunPipelineActivityResponseTypeDef",
     {
-        "payloads": List[Union[bytes, IO[bytes], StreamingBody]],
+        "payloads": List[bytes],
         "logResult": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 _RequiredS3DestinationConfigurationTypeDef = TypedDict(
@@ -1077,12 +1467,35 @@ class S3DestinationConfigurationTypeDef(
     pass
 
 
+_RequiredSampleChannelDataRequestRequestTypeDef = TypedDict(
+    "_RequiredSampleChannelDataRequestRequestTypeDef",
+    {
+        "channelName": str,
+    },
+)
+_OptionalSampleChannelDataRequestRequestTypeDef = TypedDict(
+    "_OptionalSampleChannelDataRequestRequestTypeDef",
+    {
+        "maxMessages": int,
+        "startTime": Union[datetime, str],
+        "endTime": Union[datetime, str],
+    },
+    total=False,
+)
+
+
+class SampleChannelDataRequestRequestTypeDef(
+    _RequiredSampleChannelDataRequestRequestTypeDef, _OptionalSampleChannelDataRequestRequestTypeDef
+):
+    pass
+
+
 SampleChannelDataResponseTypeDef = TypedDict(
     "SampleChannelDataResponseTypeDef",
     {
-        "payloads": List[Union[bytes, IO[bytes], StreamingBody]],
+        "payloads": List[bytes],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 ScheduleTypeDef = TypedDict(
@@ -1144,12 +1557,44 @@ class SqlQueryDatasetActionTypeDef(
     pass
 
 
+_RequiredStartPipelineReprocessingRequestRequestTypeDef = TypedDict(
+    "_RequiredStartPipelineReprocessingRequestRequestTypeDef",
+    {
+        "pipelineName": str,
+    },
+)
+_OptionalStartPipelineReprocessingRequestRequestTypeDef = TypedDict(
+    "_OptionalStartPipelineReprocessingRequestRequestTypeDef",
+    {
+        "startTime": Union[datetime, str],
+        "endTime": Union[datetime, str],
+        "channelMessages": "ChannelMessagesTypeDef",
+    },
+    total=False,
+)
+
+
+class StartPipelineReprocessingRequestRequestTypeDef(
+    _RequiredStartPipelineReprocessingRequestRequestTypeDef,
+    _OptionalStartPipelineReprocessingRequestRequestTypeDef,
+):
+    pass
+
+
 StartPipelineReprocessingResponseTypeDef = TypedDict(
     "StartPipelineReprocessingResponseTypeDef",
     {
         "reprocessingId": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+TagResourceRequestRequestTypeDef = TypedDict(
+    "TagResourceRequestRequestTypeDef",
+    {
+        "resourceArn": str,
+        "tags": List["TagTypeDef"],
     },
-    total=False,
 )
 
 TagTypeDef = TypedDict(
@@ -1188,6 +1633,93 @@ TriggeringDatasetTypeDef = TypedDict(
     },
 )
 
+UntagResourceRequestRequestTypeDef = TypedDict(
+    "UntagResourceRequestRequestTypeDef",
+    {
+        "resourceArn": str,
+        "tagKeys": List[str],
+    },
+)
+
+_RequiredUpdateChannelRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateChannelRequestRequestTypeDef",
+    {
+        "channelName": str,
+    },
+)
+_OptionalUpdateChannelRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateChannelRequestRequestTypeDef",
+    {
+        "channelStorage": "ChannelStorageTypeDef",
+        "retentionPeriod": "RetentionPeriodTypeDef",
+    },
+    total=False,
+)
+
+
+class UpdateChannelRequestRequestTypeDef(
+    _RequiredUpdateChannelRequestRequestTypeDef, _OptionalUpdateChannelRequestRequestTypeDef
+):
+    pass
+
+
+_RequiredUpdateDatasetRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateDatasetRequestRequestTypeDef",
+    {
+        "datasetName": str,
+        "actions": List["DatasetActionTypeDef"],
+    },
+)
+_OptionalUpdateDatasetRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateDatasetRequestRequestTypeDef",
+    {
+        "triggers": List["DatasetTriggerTypeDef"],
+        "contentDeliveryRules": List["DatasetContentDeliveryRuleTypeDef"],
+        "retentionPeriod": "RetentionPeriodTypeDef",
+        "versioningConfiguration": "VersioningConfigurationTypeDef",
+        "lateDataRules": List["LateDataRuleTypeDef"],
+    },
+    total=False,
+)
+
+
+class UpdateDatasetRequestRequestTypeDef(
+    _RequiredUpdateDatasetRequestRequestTypeDef, _OptionalUpdateDatasetRequestRequestTypeDef
+):
+    pass
+
+
+_RequiredUpdateDatastoreRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateDatastoreRequestRequestTypeDef",
+    {
+        "datastoreName": str,
+    },
+)
+_OptionalUpdateDatastoreRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateDatastoreRequestRequestTypeDef",
+    {
+        "retentionPeriod": "RetentionPeriodTypeDef",
+        "datastoreStorage": "DatastoreStorageTypeDef",
+        "fileFormatConfiguration": "FileFormatConfigurationTypeDef",
+    },
+    total=False,
+)
+
+
+class UpdateDatastoreRequestRequestTypeDef(
+    _RequiredUpdateDatastoreRequestRequestTypeDef, _OptionalUpdateDatastoreRequestRequestTypeDef
+):
+    pass
+
+
+UpdatePipelineRequestRequestTypeDef = TypedDict(
+    "UpdatePipelineRequestRequestTypeDef",
+    {
+        "pipelineName": str,
+        "pipelineActivities": List["PipelineActivityTypeDef"],
+    },
+)
+
 _RequiredVariableTypeDef = TypedDict(
     "_RequiredVariableTypeDef",
     {
